# -*- coding: utf-8 -*-

"""Top-level package for pymergedocx."""

from .pymergedocx import merge_docx

__author__ = """x-debug"""
__email__ = '512766594@qq.com'
__version__ = '0.1.0'
__all__ = ['merge_docx']
